%define module		sympy
# Disable for now: https://github.com/sympy/sympy/issues/24306
%define check_tests	0
%define docu 0

Summary:	Python library for symbolic mathematics
Name:		python-%{module}
Version:	1.11.1
Release:	%mkrel 1
License:	BSD
Group:		Development/Python
Url:		https://www.sympy.org/
Source0:	https://github.com/%{module}/%{module}/releases/download/%{module}-%{version}/%{module}-%{version}.tar.gz

BuildArch:	noarch
BuildRequires:  pyproject-rpm-macros
BuildRequires:	graphviz
# For docs
BuildRequires:	python3-sphinx
BuildRequires:	python3-matplotlib
BuildRequires:	python3-sphinx-math-dollar
BuildRequires:	librsvg
BuildRequires:	imagemagick
BuildRequires:	texlive-dist
# for tests
BuildRequires:	x11-font-type1
BuildRequires:	x11-server-xvfb
BuildRequires:	locales-en

%description
SymPy is a Python library for symbolic mathematics. It aims to become
a full-featured computer algebra system (CAS) while keeping the code
as simple as possible in order to be comprehensible and easily
extensible. SymPy is written entirely in Python and does not require
any external libraries, except optionally for plotting support.

%package texmacs
Summary:	TeXmacs integration for sympy
Group:		Development/Python
Requires:	%{name} = %{version}-%{release}
Requires:	texmacs

%description texmacs
This package contains a TeXmacs plugin for sympy.

%package examples
Summary:	Sympy examples
Group:		Development/Python
Requires:	%{name} = %{version}-%{release}

%description examples
This package contains example input for sympy.

%if %docu
%package doc
Summary:	Documentation for sympy
Group:		Development/Python

%description doc
man and HTML documentation for sympy.
%endif

%package -n python3-%{module}
Summary:	Python 3 library for symbolic mathematics
Group:		Development/Python
BuildRequires:	python3-devel
BuildRequires:	python3-mpmath
Requires:	python3-numpy
Requires:	python3-mpmath
Requires:	python3-matplotlib
Requires:	python3-pyglet
%{?python_provide:%python_provide python3-%{module}}

%description -n python3-%{module}
SymPy is a Python 3 library for symbolic mathematics. It aims to become
a full-featured computer algebra system (CAS) while keeping the code
as simple as possible in order to be comprehensible and easily
extensible. SymPy is written entirely in Python 3 and does not require
any external libraries, except optionally for plotting support.

%prep
%setup -q -n sympy-%{version}
%autopatch -p1

# Do not depend on env
for fil in $(grep -rl "^#\![[:blank:]]*%{_bindir}/env" .); do
  sed -i.orig 's,^\(#\![[:blank:]]*%{_bindir}/\)env python,\1python3,' $fil
  touch -r $fil.orig $fil
  rm -f $fil.orig
done

%build
%pyproject_wheel

# Build the documentation
%if %docu
pushd doc
make html SPHINXOPTS=%{?_smp_mflags} PYTHON=%{python3}
make cheatsheet
popd
# leftovers
rm -rf doc/_build/html/.buildinfo
%endif

%install
%pyproject_install
%pyproject_save_files sympy isympy

# Remove extra files
rm -f %{buildroot}%{_bindir}/{,doc}test

# Install the TeXmacs integration
cp -p data/TeXmacs/bin/tm_sympy %{buildroot}%{_bindir}

# Don't let an executable script go into the documentation
chmod a-x examples/all.py

%if %docu
# Install the HTML documentation
mkdir -p %{buildroot}%{_docdir}/%{name}-doc
cp -a doc/_build/html %{buildroot}%{_docdir}/%{name}-doc
rm -fr %{buildroot}%{_docdir}/%{name}-doc/i18n
%endif

%if 0%check_tests
%check
# The python3 tests fail with Unicode errors without this
export LC_ALL=en_US.UTF-8
let "dnum = $RANDOM % 90 + 10"
xvfb-run -n $dnum python3 setup.py test
%endif

%files texmacs
%doc data/TeXmacs/LICENSE
%{_bindir}/tm_sympy

%files examples
%doc examples

%if %docu
%files doc
%docdir %{_docdir}/%{name}-doc/html
%{_docdir}/%{name}-doc/html
%endif

%files -n python3-%{module} -f %{pyproject_files}
%doc AUTHORS LICENSE PKG-INFO
%{_mandir}/man1/isympy.1*
%{_bindir}/isympy


%changelog
* Wed Dec 14 2022 papoteur <papoteur> 1.11.1-1.mga9
+ Revision: 1922024
- new 1.11.1

* Wed Apr 06 2022 umeabot <umeabot> 1.7.1-4.mga9
+ Revision: 1846133
- Mageia 9 Mass Rebuild

* Thu Feb 17 2022 tv <tv> 1.7.1-3.mga9
+ Revision: 1779227
- Rebuild for python-3.10

* Sat May 01 2021 daviddavid <daviddavid> 1.7.1-2.mga9
+ Revision: 1720669
- fix preview of PNG images (mga#28862)
- add missing dependency on python3-pyglet (mga#28862)

* Sun Apr 04 2021 joequant <joequant> 1.7.1-1.mga9
+ Revision: 1713313
- add tex for build
- add buildrequires
- update to 1.7.1 / python 3.9
+ tv <tv>
- Rebuild for python 3.9

* Tue Jan 12 2021 daviddavid <daviddavid> 1.4-5.mga8
+ Revision: 1671262
- do not package "/usr/share/TeXmacs/plugins/sympy/progs/init-sympy.scm"
  plugin anymore as now texmacs provided it directly

* Sun Jul 05 2020 joequant <joequant> 1.4-4.mga8
+ Revision: 1602400
- fix shebangs
- bump
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Mon Sep 23 2019 tv <tv> 1.4-2.mga8
+ Revision: 1444922
- rebuild for python-3.8
- drop python2 subpkg

* Sun Aug 25 2019 wally <wally> 1.4-1.mga8
+ Revision: 1431863
- new version 1.4

* Thu Jan 10 2019 daviddavid <daviddavid> 1.3-2.mga7
+ Revision: 1354116
- rebuild for new Python 3.7

* Sun Sep 30 2018 joequant <joequant> 1.3-1.mga7
+ Revision: 1312563
- add python3 byte-compile
- add isympy.py
- add graphviz
- update to 1.3
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild
- Mageia 7 Mass Rebuild

* Sat Aug 05 2017 pterjan <pterjan> 1.0-3.mga7
+ Revision: 1135654
- Rebuild for python 3.6
+ joequant <joequant>
- revert to previous build.  build problems were with build system

* Tue Apr 19 2016 joequant <joequant> 1.0-1.mga6
+ Revision: 1003550
- fix build typo
- update to 1.0

* Sat Feb 20 2016 umeabot <umeabot> 0.7.6.1-3.mga6
+ Revision: 971174
- Mageia 6 Mass Rebuild

* Sun Oct 11 2015 joequant <joequant> 0.7.6.1-2.mga6
+ Revision: 889446
- simplify and upgrade to 3.5
- revert python-sympy removal

* Thu Sep 24 2015 philippem <philippem> 0.7.6.1-1.mga6
+ Revision: 883378
- update to 0.7.6.1

* Wed Jan 28 2015 joequant <joequant> 0.7.6-1.mga5
+ Revision: 812581
- add imagemagick
- fix comments
- add librsvg to sympy
- update sympy to 0.7.6

* Wed Oct 15 2014 umeabot <umeabot> 0.7.3-8.mga5
+ Revision: 746274
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 0.7.3-7.mga5
+ Revision: 729867
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 0.7.3-6.mga5
+ Revision: 688373
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Sat May 31 2014 pterjan <pterjan> 0.7.3-5.mga5
+ Revision: 629051
- Rebuild for new Python

* Fri Nov 22 2013 philippem <philippem> 0.7.3-4.mga4
+ Revision: 552336
- add missing requires python-mpmath and python-matplotlib fix mga#11736

* Tue Oct 22 2013 umeabot <umeabot> 0.7.3-3.mga4
+ Revision: 544340
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 0.7.3-2.mga4
+ Revision: 499514
- Rebuild to add different pythonegg provides for python 2 and 3

* Thu Oct 03 2013 philippem <philippem> 0.7.3-1.mga4
+ Revision: 490623
-update to 0.7.3
- add Python 3
- split doc , examples and texmacs in subpackages

* Sun Jan 13 2013 umeabot <umeabot> 0.7.1-2.mga3
+ Revision: 379552
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Sep 20 2011 lebedov <lebedov> 0.7.1-1.mga2
+ Revision: 146159
- imported package python-sympy

